##  Introduce New Subsections and Fields to Business Capability
In the Meta Model v4, a new subsection called Maturity has been introduced to capture the business capabilities' current and target maturity levels. To add the new subsection to your Meta Model v3, summarily, do the following:
  1. Add a subsection named “Maturity” and provide the necessary translations.
  2. Within the newly created subsection, introduce new Fact Sheet fields for Current Maturity, Target Maturity, Strategic Importance, and Maturity Description.
